# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have a old versions of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

Name:		perl-Scalar-Properties
Version:	1.100860
Release:	10.%{__distinit}%{__distvers}
Summary:	Run-time properties on scalar variables
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Scalar-Properties/
Source0:	http://search.cpan.org/CPAN/authors/id/M/MA/MARCEL/Scalar-Properties-%{version}.tar.gz
Patch1:		Scalar-Properties-1.100860-Test::More-done_testing.patch
Patch2:		Scalar-Properties-1.100860-Test::More-note.patch
Patch3:		Scalar-Properties-1.100860-skip-MYMETA.yml.patch
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# ===================================================================
# Build requirements
# ===================================================================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.11
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# ===================================================================
# Test requirements
# ===================================================================
BuildRequires:	perl(Carp)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Test::More)
# ===================================================================
# Author test requirements
# (skipped as the Critic test fails in version 1.100860)
# ===================================================================
BuildRequires:	perl(English)
BuildConflicts:	perl(Test::Perl::Critic)
# ===================================================================
# Release test requirements
# (Spelling check can't find "versa" in version 1.100860)
# ===================================================================
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildConflicts:	perl(Pod::Wordlist::hanekomu)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::HasVersion)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling), aspell-en
BuildRequires:	perl(Test::Synopsis)
# ===================================================================
# Runtime requirements
# ===================================================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Scalar::Properties attempts to make Perl more object-oriented by taking an idea
from Ruby: Everything you manipulate is an object, and the results of those
manipulations are objects themselves.

%prep
%setup -q -n Scalar-Properties-%{version}

# done_testing requires Test::More ≥ 0.88
%if %{old_test_more}
%patch1 -p1
%endif

# note() requires Test::More ≥ 0.82
%if %{older_test_more}
%patch2 -p1
%endif

# MANIFEST.SKIP should include MYMETA.yml; otherwise, t/release-dist-manifest.t
# may fail due to it appearing unexpectedly
%patch3 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test AUTHOR_TESTING=1 RELEASE_TESTING=1

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Scalar/
%{_mandir}/man3/Scalar::Properties.3*

%changelog
* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 1.100860-10
- BR: perl-generators where available
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 1.100860-6
- Drop support for building with ExtUtils::MakeMaker < 6.30
- BR: perl(Test::Synopsis) unconditionally
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 1.100860-2
- Update MYMETA.yml patch to include MYMETA.json too
- Drop non-dual-lived Perl core buildreqs
- Drop support for old distribution prior to FC-3:
  - Always BuildConflict with Test::Perl::Critic
  - Never need aspell-en-gb
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> - 1.100860-1
- Import from Fedora
- Update to 1.100860

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.13-10
- Perl mass rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.13-8
- Rebuild to fix problems with vendorarch/lib (#661697)

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.13-7
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.13-6
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Nov 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-3
- Fix source url

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-1.1
- BR: Test::More

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.13-1
- 0.13

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.12-1.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Sun Apr 09 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.12-1
- First build
